# Pygments Ashen

This repository contains the Pygments style plugin for the
[Ashen](https://sr.ht/~ficd/ashen) theme. Available as the `pygments-ashen`
package for use in your Python projects, or with the Pygments CLI tool.
